<?php /* Smarty version 2.6.20, created on 2008-12-29 17:57:24
         compiled from header_index.tpl */ ?>
<div id="header">
<div id="header_login_index">
<?php if ($this->_tpl_vars['session_status'] == true): ?>

	<ul>
	<li><a href="userinfo.php">鈴木将之さんの情報</a></li>
	<li><a href="logout.php">ログアウト</a></li>
	</ul>
<?php else: ?>
	<ul>
	<li><a href="login.php">ログイン</a></li>
	<li><a href="entry.php">会員登録</a></li>
	</ul>
<?php endif; ?>

</div> 
	<div id="header_menu_index">
		<ul id="header_ul">
      		      		<li><a href="index.php">TOP</a></li>
      		<li><a href="book_search.php?switch=all">一覧</a></li>
      		<li><a href="">HELP</a></li>
      		<li></li>
    	</ul>
  </div> 
</div> 
